==> gst-plugins-0.5.0.tar.bz2: gst-plugins-0.5.0/ext/mpeg2dec/gstmpeg2dec.h <==
/* GStreamer
 * Copyright (C) <1999> Erik Walthinsen <omega@cse.ogi.edu>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef __GST_MPEG2DEC_H__
#define __GST_MPEG2DEC_H__


#include <config.h>
#include <gst/gst.h>
#include <mpeg2dec/mpeg2.h>
#include <mpeg2dec/mm_accel.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define GST_TYPE_MPEG2DEC \
  (gst_mpeg2dec_get_type())
#define GST_MPEG2DEC(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_MPEG2DEC,GstMpeg2dec))
#define GST_MPEG2DEC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_MPEG2DEC,GstMpeg2dec))
#define GST_IS_MPEG2DEC(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_MPEG2DEC))
#define GST_IS_MPEG2DEC_CLASS(obj) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_MPEG2DEC))

#define MPEGTIME_TO_GSTTIME(time) (((time) * (GST_MSECOND/10)) / 9LL)
#define GSTTIME_TO_MPEGTIME(time) (((time) * 9LL) / (GST_MSECOND/10))

typedef struct _GstMpeg2dec GstMpeg2dec;
typedef struct _GstMpeg2decClass GstMpeg2decClass;

typedef enum
{
  MPEG2DEC_FORMAT_NONE,
  MPEG2DEC_FORMAT_I420,
  MPEG2DEC_FORMAT_YV12,
} Mpeg2decFormat;

struct _GstMpeg2dec {
  GstElement 	 element;

  /* pads */
  GstPad 	*sinkpad,
  		*srcpad;
  GstBufferPool *peerpool;

  mpeg2dec_t 	*decoder;
  guint32	 accel;
  gboolean	 closed;

  /* the timestamp of the next frame */
  gboolean	 first;
  gboolean	 discont_pending;
  gint64	 next_time;
  gint64	 last_PTS;

  /* video state */
  Mpeg2decFormat format;
  gint		 width;
  gint		 height;
  gint		 pixel_width;
  gint		 pixel_height;
  gint		 frame_rate_code;
  gint64	 total_frames;
  gint64	 frame_period;

  GstCache	*cache;
  gint		 cache_id;
};

struct _GstMpeg2decClass {
  GstElementClass parent_class;
};

GType gst_mpeg2dec_get_type(void);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GST_MPEG2DEC_H__ */

==> gst-plugins-0.7.2.tar.bz2: gst-plugins-0.7.2/ext/mpeg2dec/gstmpeg2dec.h <==
/* GStreamer
 * Copyright (C) <1999> Erik Walthinsen <omega@cse.ogi.edu>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef __GST_MPEG2DEC_H__
#define __GST_MPEG2DEC_H__


#include <gst/gst.h>
#include <mpeg2.h>

G_BEGIN_DECLS

#define GST_TYPE_MPEG2DEC \
  (gst_mpeg2dec_get_type())
#define GST_MPEG2DEC(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_MPEG2DEC,GstMpeg2dec))
#define GST_MPEG2DEC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_MPEG2DEC,GstMpeg2dec))
#define GST_IS_MPEG2DEC(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_MPEG2DEC))
#define GST_IS_MPEG2DEC_CLASS(obj) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_MPEG2DEC))

#define MPEGTIME_TO_GSTTIME(time) (((time) * (GST_MSECOND/10)) / 9LL)
#define GSTTIME_TO_MPEGTIME(time) (((time) * 9LL) / (GST_MSECOND/10))

typedef struct _GstMpeg2dec GstMpeg2dec;
typedef struct _GstMpeg2decClass GstMpeg2decClass;

typedef enum
{
  MPEG2DEC_FORMAT_NONE,
  MPEG2DEC_FORMAT_I420,
  MPEG2DEC_FORMAT_YV12,
} Mpeg2decFormat;

typedef enum 
{
  MPEG2DEC_DISC_NONE 		= 0,
  MPEG2DEC_DISC_NEW_PICTURE,
  MPEG2DEC_DISC_NEW_KEYFRAME,
} DiscontState;

struct _GstMpeg2dec {
  GstElement 	 element;

  /* pads */
  GstPad 	*sinkpad,
  		*srcpad,
  		*userdatapad;
  GstBufferPool *peerpool;

  mpeg2dec_t 	*decoder;
  gboolean	 closed;
  gboolean	 have_fbuf;

  /* the timestamp of the next frame */
  DiscontState	 discont_state;
  gint64	 next_time;
  gint64	 segment_start;
  gint64	 segment_end;

  /* video state */
  Mpeg2decFormat format;
  gint		 width;
  gint		 height;
  gint		 pixel_width;
  gint		 pixel_height;
  gint		 frame_rate_code;
  gint64	 total_frames;
  gint64	 frame_period;
  gboolean	 need_sequence;

  GstCaps	*streaminfo;
  GstEvent	*pending_event;

  GstIndex	*index;
  gint		 index_id;
};

struct _GstMpeg2decClass {
  GstElementClass parent_class;
};

GType gst_mpeg2dec_get_type(void);

G_END_DECLS

#endif /* __GST_MPEG2DEC_H__ */
